.. _getting_started:

Getting Started
=================

This is a simple step by step guide on how to test Google Analytics 
implementations with GAUnit.

At the end of this guide, **you will be able to perform manual and automatic tests with GAUnit**.

First, make sure you have Python and GAUnit installed (see :ref:`install`).

This tutorial has 4 parts:

.. toctree::
   :maxdepth: 1

   getting_started/the_scenario
   getting_started/write_your_tracking_plan
   getting_started/manual_check
   getting_started/automatic_test_with_selenium

*The last 2 parts can be done independantly.*

**Click on 'Next
' to start!**